import numpy as np
import scipy.constants as const



def find_force_at_lattice_sigma():
    """What total force do we get with the actual lattice QCD sigma?"""
    
    # Same parameters as before
    F_geometric = 1.70e4  # N
    F_coulomb = 1.79e4    # N
    
    # Use actual lattice QCD value
    sigma_lattice = 0.18  # GeV/fm
    sigma_N = sigma_lattice * (const.e * 1e9 / 1e-15)
    
    F_total = F_geometric + F_coulomb + sigma_N
    
    print(f"\nWITH LATTICE QCD σ = 0.18 GeV/fm:")
    print(f"F_geometric = {F_geometric:.2e} N")
    print(f"F_coulomb   = {F_coulomb:.2e} N") 
    print(f"F_confine   = {sigma_N:.2e} N")
    print(f"F_total     = {F_total:.2e} N")
    print(f"\nThis gives nuclear forces of ~{F_total:.0e} N")

find_force_at_lattice_sigma()
